@@ -129,6 +129,7 @@ class AlgebraicMixin:
         derived_compounds=None,
         modifiers=None,
         parameters=None,
+        args=None,
         **meta_info,
     ):
         """Add an algebraic module to the model.
@@ -183,6 +184,8 @@ class AlgebraicMixin:
             modifiers = []
         if parameters is None:
             parameters = []
+        if args is None:
+            args = compounds + modifiers + parameters
 
         patch_lambda_function_name(function=function, name=module_name)
 
@@ -196,6 +199,7 @@ class AlgebraicMixin:
             "derived_compounds": derived_compounds,
             "modifiers": modifiers,
             "parameters": parameters,
+            "args": args,
         }
         for compound in derived_compounds:
             self._add_derived_compound(compound=compound)
@@ -231,7 +235,7 @@ class AlgebraicMixin:
         derived_compounds=None,
         modifiers=None,
         parameters=None,
-        **meta_info,
+        args=None,
     ):
         """Update an existing reaction.
 
@@ -249,32 +253,44 @@ class AlgebraicMixin:
             Names of compounds which act as modifiers on the module
         parameters : iterable(str)
             Names of the parameters which are passed to the function
-        meta_info : dict(module_name, meta_info)
-            Meta info of the algebraic module. Allowed keys are
-            {common_name, notes, database_links}
         """
-        if function is None:
-            function = self.algebraic_modules[module_name]["function"]
-        if compounds is None:
-            compounds = self.algebraic_modules[module_name]["compounds"]
-        if derived_compounds is None:
-            derived_compounds = self.algebraic_modules[module_name]["derived_compounds"]
-        if modifiers is None:
-            modifiers = self.algebraic_modules[module_name]["modifiers"]
-        if parameters is None:
-            parameters = self.algebraic_modules[module_name]["parameters"]
-        meta = self.meta_info["modules"][module_name].__dict__
-        meta.update(meta_info)
-        self.remove_algebraic_module(module_name=module_name)
-        self.add_algebraic_module(
-            module_name=module_name,
-            function=function,
-            compounds=compounds,
-            derived_compounds=derived_compounds,
-            modifiers=modifiers,
-            parameters=parameters,
-            **meta,
-        )
+        module = self.algebraic_modules[module_name]
+        args_have_changed = False
+        if function is not None:
+            patch_lambda_function_name(function=function, name=module_name)
+            module["function"] = function
+        if compounds is not None:
+            module["compounds"] = compounds
+            args_have_changed = True
+        if derived_compounds is not None:
+            old_compounds = module["derived_compounds"]
+
+            # If there are now less derived compounds, remove the excess ones
+            if len(derived_compounds) < len(old_compounds):
+                for compound in old_compounds[len(derived_compounds) :]:
+                    self.derived_compounds.remove(compound)
+
+            # Update old derived compounds (keeping their order)
+            replacements = dict(zip(old_compounds, derived_compounds))
+            self.derived_compounds = [replacements.get(x, x) for x in self.derived_compounds]
+
+            # Add new derived compounds (if there are any)
+            for compound in derived_compounds[len(replacements) :]:
+                self._add_derived_compound(compound=compound)
+
+            module["derived_compounds"] = derived_compounds
+            args_have_changed = True
+        if modifiers is not None:
+            module["modifiers"] = modifiers
+            args_have_changed = True
+        if parameters is not None:
+            module["parameters"] = parameters
+            args_have_changed = True
+        if args is not None:
+            module["args"] = args
+        else:
+            if args_have_changed:
+                module["args"] = module["compounds"] + module["modifiers"] + module["parameters"]
 
     def update_module_meta_info(self, module, meta_info):
         """Update meta info of an algebraic module.
@@ -386,18 +402,22 @@ class AlgebraicMixin:
             A dictionary of the concentrations of all non-derived compounds
         """
         y["time"] = t
-        for module in self.algebraic_modules.values():
-            derived_values = module["function"](
-                *(y[var] for var in module["compounds"]),
-                *(y[var] for var in module["modifiers"]),
-                *(self.parameters[par] for par in module["parameters"]),
-            )
-            y.update(
+        # args = self.parameters | y # that is python 3.9+ syntax, wait for a bit
+        args = {**self.parameters, **y}
+        for name, module in self.algebraic_modules.items():
+            try:
+                derived_values = module["function"](*(args[arg] for arg in module["args"]))
+            except KeyError as e:
+                raise KeyError(f"Could not find argument {e} for module {name}")
+            derived_compounds = dict(
                 zip(
                     module["derived_compounds"],
                     np.array(derived_values).reshape((len(module["derived_compounds"]), -1)),
                 )
             )
+            y.update(derived_compounds)
+            args.update(derived_compounds)
+        # return dict(set(args) - set(self.parameters)) # alternative solution, think about it
         return y
 
     ##########################################################################
