@@ -68,6 +68,7 @@ class RateMixin:
         dynamic_variables=None,
         parameters=None,
         reversible=False,
+        args=None,
         **meta_info,
     ):
         """Add a rate function to the model.
@@ -136,6 +137,8 @@ class RateMixin:
                 dynamic_variables = substrates + products + modifiers
             else:
                 dynamic_variables = substrates + modifiers
+        if args is None:
+            args = dynamic_variables + parameters
 
         if function.__name__ == "<lambda>":
             patch_lambda_function_name(function=function, name=rate_name)
@@ -151,6 +154,7 @@ class RateMixin:
             "modifiers": modifiers,
             "dynamic_variables": dynamic_variables,
             "reversible": reversible,
+            "args": args,
         }
         self.meta_info.setdefault("rates", {}).setdefault(rate_name, Rate(**meta_info))
 
@@ -184,6 +188,7 @@ class RateMixin:
         modifiers=None,
         parameters=None,
         reversible=None,
+        args=None,
         **meta_info,
     ):
         """Update an existing rate.
@@ -212,18 +217,21 @@ class RateMixin:
         --------
         add_rate
         """
+        old_rate = self.rates[rate_name]
         if function is None:
-            function = self.rates[rate_name]["function"]
+            function = old_rate["function"]
         if substrates is None:
-            substrates = self.rates[rate_name]["substrates"]
+            substrates = old_rate["substrates"]
         if products is None:
-            products = self.rates[rate_name]["products"]
+            products = old_rate["products"]
         if parameters is None:
-            parameters = self.rates[rate_name]["parameters"]
+            parameters = old_rate["parameters"]
         if modifiers is None:
-            modifiers = self.rates[rate_name]["modifiers"]
+            modifiers = old_rate["modifiers"]
         if reversible is None:
-            reversible = self.rates[rate_name]["reversible"]
+            reversible = old_rate["reversible"]
+        if args is None:
+            args = old_rate["args"]
 
         meta = self.meta_info["rates"][rate_name].__dict__
         meta.update(meta_info)
@@ -237,6 +245,7 @@ class RateMixin:
             modifiers=modifiers,
             parameters=parameters,
             reversible=reversible,
+            args=args,
             **meta,
         )
 
@@ -375,7 +384,7 @@ class RateMixin:
     # Simulation functions
     ##########################################################################
 
-    def _get_fluxes(self, *, y):
+    def _get_fluxes(self, *, fcd: dict):
         """Calculate the fluxes.
 
         This is the performance optimized version of the function
@@ -390,15 +399,14 @@ class RateMixin:
         rates : dict(str: num)
             Dictionary containing all calculated rates
         """
+        # args = self.parameters | fcd # python 3.9+ syntax
+        args = {**self.parameters, **fcd}
         fluxes = {}
         for name, rate in self.rates.items():
             try:
-                fluxes[name] = rate["function"](
-                    *(y[var] for var in rate["dynamic_variables"]),
-                    *(self.parameters[par] for par in rate["parameters"]),
-                )
+                fluxes[name] = rate["function"](*(args[arg] for arg in rate["args"]))
             except KeyError as e:
-                raise KeyError(f"Could not find compound {e} for rate {name}")
+                raise KeyError(f"Could not find argument {e} for rate {name}")
         return fluxes
 
     ##########################################################################
