@@ -285,8 +285,8 @@ class Model(
         fluxes : dict
         """
         self._update_derived_parameters()
-        y = self.get_full_concentration_dict(y=y, t=t)
-        return {k: np.ones(len(y["time"])) * v for k, v in self._get_fluxes(y=y).items()}
+        fcd = self.get_full_concentration_dict(y=y, t=t)
+        return {k: np.ones(len(fcd["time"])) * v for k, v in self._get_fluxes(fcd=fcd).items()}
 
     def get_fluxes_array(self, y, t=0):
         """Calculate the fluxes at time point(s) t.
@@ -340,7 +340,7 @@ class Model(
         """
         y = dict(zip(self.get_compounds(), np.array(y).reshape(-1, 1)))
         fcd = self._get_fcd(t=t, y=y)
-        fluxes = self._get_fluxes(y=fcd)
+        fluxes = self._get_fluxes(fcd=fcd)
         compounds_local = self.get_compounds()
         dxdt = dict(zip(compounds_local, np.zeros(len(compounds_local))))
         for k, stoc in self.stoichiometries_by_compounds.items():
