@@ -474,6 +474,24 @@ class Parser:
             else:
                 self.converted_variables[sbml_id] = compound
 
+    def _replace_function_with_operators(self, algebraic_rule):
+        rule_body = algebraic_rule.function_body
+        if "," not in rule_body:
+            return None
+
+        for func_id, function in self.parsed_functions.items():
+            func_pattern = re.compile(f"{func_id}\(.+\)")
+            matches = re.findall(func_pattern, rule_body)
+            for match in matches:
+                func_body = function.function_body
+                func_args = function.function_args
+                parts = match[len(f"{func_id}(") : -1].split(", ")
+                for arg, repl in zip(func_args, parts):
+                    func_body = re.sub(arg, f"({repl})", func_body)
+                rule_body = re.sub(func_pattern, func_body, rule_body)
+
+        algebraic_rule.function_body = rule_body
+
     def _convert_algebraic_to_assignment_rule(self, rule):
         parsed_args = rule.parsed_args
         # isolate derived_compound
@@ -489,6 +507,7 @@ class Parser:
         parsed_args.remove(derived_compound)
 
         # solve equation for derived compound
+        self._replace_function_with_operators(algebraic_rule=rule)
         try:
             eq = sympy.parse_expr(str(rule.function_body))
             function_body = str(sympy.solve(eq, derived_compound)[0])
@@ -804,7 +823,6 @@ class Parser:
         func_str = "\n".join(
             [
                 f"def {func_name}({func_args}):",
-                f"{INDENT}# {func.sbml_math}",
                 f"{INDENT}return {func_body}",
                 "",
             ]
