@@ -195,6 +195,31 @@ class ModelAlgebraicModuleTests(unittest.TestCase):
         self.assertEqual(model.algebraic_modules["mod1"]["derived_compounds"], ["x", "y"])
         self.assertEqual(model.algebraic_modules["mod1"]["parameters"], ["keq"])
 
+    def test_update_algebraic_module_less_derived_compounds(self):
+        parameters = {"keq1": 1, "keq2": 2}
+        model = Model(parameters=parameters)
+        model.add_compounds(["A1", "A2"])
+        model.add_algebraic_module(
+            module_name="mod1",
+            function=lambda s, keq: (s / (1 + keq), (s * keq / (1 + keq))),
+            compounds=["A1"],
+            derived_compounds=["x1", "y1"],
+            parameters=["keq1"],
+        )
+        model.update_algebraic_module(
+            module_name="mod1",
+            function=lambda s, keq: (s / (1 + keq), (s * keq / (1 + keq))),
+            compounds=["A2"],
+            derived_compounds=["x2"],
+            parameters=["keq2"],
+        )
+        self.assertEqual(model.compounds, ["A1", "A2"])
+        self.assertEqual(model.derived_compounds, ["x2"])
+        self.assertEqual(model.algebraic_modules["mod1"]["function"].__name__, "mod1")
+        self.assertEqual(model.algebraic_modules["mod1"]["compounds"], ["A2"])
+        self.assertEqual(model.algebraic_modules["mod1"]["derived_compounds"], ["x2"])
+        self.assertEqual(model.algebraic_modules["mod1"]["parameters"], ["keq2"])
+
     def test_update_algebraic_module(self):
         parameters = {"keq1": 1, "keq2": 2}
         model = Model(parameters=parameters)
@@ -220,6 +245,31 @@ class ModelAlgebraicModuleTests(unittest.TestCase):
         self.assertEqual(model.algebraic_modules["mod1"]["derived_compounds"], ["x2", "y2"])
         self.assertEqual(model.algebraic_modules["mod1"]["parameters"], ["keq2"])
 
+    def test_update_algebraic_module_more_derived_compounds(self):
+        parameters = {"keq1": 1, "keq2": 2}
+        model = Model(parameters=parameters)
+        model.add_compounds(["A1", "A2"])
+        model.add_algebraic_module(
+            module_name="mod1",
+            function=lambda s, keq: (s / (1 + keq), (s * keq / (1 + keq))),
+            compounds=["A1"],
+            derived_compounds=["x1", "y1"],
+            parameters=["keq1"],
+        )
+        model.update_algebraic_module(
+            module_name="mod1",
+            function=lambda s, keq: (s / (1 + keq), (s * keq / (1 + keq))),
+            compounds=["A2"],
+            derived_compounds=["x2", "y2", "z2"],
+            parameters=["keq2"],
+        )
+        self.assertEqual(model.compounds, ["A1", "A2"])
+        self.assertEqual(model.derived_compounds, ["x2", "y2", "z2"])
+        self.assertEqual(model.algebraic_modules["mod1"]["function"].__name__, "mod1")
+        self.assertEqual(model.algebraic_modules["mod1"]["compounds"], ["A2"])
+        self.assertEqual(model.algebraic_modules["mod1"]["derived_compounds"], ["x2", "y2", "z2"])
+        self.assertEqual(model.algebraic_modules["mod1"]["parameters"], ["keq2"])
+
     def test_update_algebraic_module_nothing(self):
         parameters = {"keq": 1}
         model = Model(parameters=parameters)
