@@ -43,7 +43,7 @@ class ModelErrorTests(unittest.TestCase):
             reversible=True,
         )
         with self.assertRaises(KeyError):
-            model._get_fluxes(y={"x": 2})
+            model._get_fluxes(fcd={"x": 2})
 
 
 class ModelTests(unittest.TestCase):
@@ -387,7 +387,7 @@ class FluxesTests(unittest.TestCase):
             parameters=["k_in"],
             reversible=False,
         )
-        self.assertEqual(model._get_fluxes(y={"x": 0}), {"v1": 1})
+        self.assertEqual(model._get_fluxes(fcd={"x": 0}), {"v1": 1})
 
     def test_irreversible_one_variable(self):
         parameters = {"k": 1}
@@ -402,7 +402,7 @@ class FluxesTests(unittest.TestCase):
             parameters=["k"],
             reversible=False,
         )
-        self.assertEqual(model._get_fluxes(y={"x": 2, "y": 0}), {"v1": 2})
+        self.assertEqual(model._get_fluxes(fcd={"x": 2, "y": 0}), {"v1": 2})
 
     def test_irreversible_two_variables(self):
         parameters = {"k": 1}
@@ -417,7 +417,7 @@ class FluxesTests(unittest.TestCase):
             parameters=["k"],
             reversible=False,
         )
-        self.assertEqual(model._get_fluxes(y={"x1": 2, "x2": 3, "y": 0}), {"v1": 6})
+        self.assertEqual(model._get_fluxes(fcd={"x1": 2, "x2": 3, "y": 0}), {"v1": 6})
 
     def test_reversible_one(self):
         parameters = {"kf": 1, "kr": 1}
@@ -432,7 +432,7 @@ class FluxesTests(unittest.TestCase):
             parameters=["kf", "kr"],
             reversible=True,
         )
-        self.assertEqual(model._get_fluxes(y={"x": 2, "y": 3}), {"v1": -1})
+        self.assertEqual(model._get_fluxes(fcd={"x": 2, "y": 3}), {"v1": -1})
 
     def test_reversible_two(self):
         parameters = {"kf": 1, "kr": 1}
@@ -447,7 +447,7 @@ class FluxesTests(unittest.TestCase):
             parameters=["kf", "kr"],
             reversible=True,
         )
-        self.assertEqual(model._get_fluxes(y={"x1": 2, "x2": 3, "y1": 4, "y2": 5}), {"v1": -14})
+        self.assertEqual(model._get_fluxes(fcd={"x1": 2, "x2": 3, "y1": 4, "y2": 5}), {"v1": -14})
 
     def test_irreversible_modifier(self):
         parameters = {"k": 1}
@@ -462,7 +462,7 @@ class FluxesTests(unittest.TestCase):
             parameters=["k"],
             reversible=False,
         )
-        self.assertEqual(model._get_fluxes(y={"x": 2, "y": 3, "xi": 4}), {"v1": 0.5})
+        self.assertEqual(model._get_fluxes(fcd={"x": 2, "y": 3, "xi": 4}), {"v1": 0.5})
 
     def test_reversible_modifier(self):
         parameters = {"k": 1}
@@ -477,7 +477,7 @@ class FluxesTests(unittest.TestCase):
             parameters=["k"],
             reversible=True,
         )
-        self.assertEqual(model._get_fluxes(y={"x": 2, "y": 3, "xi": 4}), {"v1": -0.25})
+        self.assertEqual(model._get_fluxes(fcd={"x": 2, "y": 3, "xi": 4}), {"v1": -0.25})
 
     def test_irreversible_modifier_time(self):
         parameters = {"k": 1}
@@ -492,7 +492,7 @@ class FluxesTests(unittest.TestCase):
             parameters=["k"],
             reversible=False,
         )
-        self.assertEqual(model._get_fluxes(y={"x": 2, "y": 3, "time": 4}), {"v1": 0.5})
+        self.assertEqual(model._get_fluxes(fcd={"x": 2, "y": 3, "time": 4}), {"v1": 0.5})
 
     def test_reversible_modifier_time(self):
         parameters = {"k": 1}
@@ -507,7 +507,7 @@ class FluxesTests(unittest.TestCase):
             parameters=["k"],
             reversible=True,
         )
-        self.assertEqual(model._get_fluxes(y={"x": 2, "y": 3, "time": 4}), {"v1": -0.25})
+        self.assertEqual(model._get_fluxes(fcd={"x": 2, "y": 3, "time": 4}), {"v1": -0.25})
 
 
 class SourceCodeTests(unittest.TestCase):
