@@ -116,7 +116,7 @@ class SimulationTests(unittest.TestCase):
         label_model.add_reaction(rate_name="v1", stoichiometry={"x": -1, "y": 1}, labelmap=[0, 1])
         y0 = label_model.generate_y0({"x": 0})
         v_ss = {"v1": 1}
-        self.assertEqual(label_model._get_fluxes(y=y0, v_ss=v_ss), {"v1__0": 1.0, "v1__1": 0})
+        self.assertEqual(label_model._get_fluxes(fcd=y0, v_ss=v_ss), {"v1__0": 1.0, "v1__1": 0})
 
     def test_get_fluxes_reverse(self):
         label_model = LinearLabelModel()
@@ -125,7 +125,7 @@ class SimulationTests(unittest.TestCase):
         y0 = label_model.generate_y0({"x": 0})
         v_ss = {"v1": 1}
 
-        self.assertEqual(label_model._get_fluxes(y=y0, v_ss=v_ss), {"v1__0": 0, "v1__1": 1.0})
+        self.assertEqual(label_model._get_fluxes(fcd=y0, v_ss=v_ss), {"v1__0": 0, "v1__1": 1.0})
 
     def test_get_fluxes_dict_array_df(self):
         v_ss = {"v1": 1}
